@@ -25,8 +25,12 @@ def building_response(buildings,observer,weather_now,actual_build,dt,setpoint,da
         e_use[cat[i]] = 0
     for k in range(n_b):
         building = buildings[k]
-        heating = setpoint['district_heat'][k]
-        cooling = setpoint['district_cool'][k]
+        heating = None
+        if 'district_heat' in setpoint:
+            heating = setpoint['district_heat'][k]
+        cooling = None
+        if 'cooling' in setpoint:
+            cooling = setpoint['district_cool'][k]
         T_optim = setpoint['temperature'][k]
         nz = len(building['zones']['name'])
         w['zone'] = observer['building_humidity'][k]
